@@ -137,8 +137,8 @@ const View = new Lang.Class({
                 this._toolbar = this.view.createToolbar(this._stack);
 
             if (this._toolbar.searchbar)
-                this._toolbar.searchbar.connectJS('activate-result',
-                                                  Lang.bind(this, this._onActivateResult));
+                this._toolbar.searchbar.connect('activate-result',
+                                                Lang.bind(this, this._onActivateResult));
             this._window.get_titlebar().add(this._toolbar);
         }
     },
@@ -214,13 +214,9 @@ const Embed = new Lang.Class({
     },
 
     getMainToolbar: function() {
-        let windowMode = Application.modeController.getWindowMode();
-
-        if (windowMode == WindowMode.WindowMode.PREVIEW_EV) {
-            let fullscreen = this._view.view.fullscreen;
-            if (fullscreen)
-                return this._view.view.getFullscreenToolbar();
-        }
+        if (this._view.view.canFullscreen &&
+            this._view.view.fullscreen)
+            return this._view.view.getFullscreenToolbar();
 
         return this._view.toolbar;
     },
