@@ -23,6 +23,7 @@ const GdPrivate = imports.gi.GdPrivate;
 const Gepub = imports.gi.Gepub;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
+const Gtk = imports.gi.Gtk;
 const WebKit2 = imports.gi.WebKit2;
 
 const _ = imports.gettext.gettext;
@@ -61,6 +62,10 @@ const EPUBView = new Lang.Class({
         return new EPUBViewToolbar(this);
     },
 
+    createNavControls: function() {
+        return new EPUBViewNavControls(this, this.overlay);
+    },
+
     createView: function() {
         let view = new Gepub.Widget();
 
@@ -95,6 +100,7 @@ const EPUBView = new Lang.Class({
         this._metadata = this._loadMetadata();
 
         this.set_visible_child_name('view');
+        this.navControls.setDocument(this._epubdoc);
     },
 
     _loadMetadata: function() {
@@ -139,7 +145,7 @@ const EPUBView = new Lang.Class({
     },
 
     get hasPages() {
-        return true;
+        return this._epubdoc ? this._epubdoc.get_n_pages() > 0 : false;
     },
 
     get page() {
@@ -193,3 +199,64 @@ const EPUBViewToolbar = new Lang.Class({
         this.addSearchButton('view.find');
     }
 });
+
+const EPUBViewNavControls = new Lang.Class({
+    Name: 'EPUBViewNavControls',
+    Extends: Preview.PreviewNavControls,
+
+    _init: function(preview, overlay) {
+        this._epubdoc = null;
+        this.parent(preview, overlay);
+    },
+
+    setDocument: function(epubdoc) {
+        this._epubdoc = epubdoc;
+
+        if (this._epubdoc != null) {
+            this._level.set_range(1.0, this.preview.numPages);
+            this._epubdoc.connect('notify::page', Lang.bind(this, function() {
+                this._updatePage();
+                this._updateVisibility();
+            }));
+            this._updatePage();
+        }
+    },
+
+    _updatePage: function() {
+        let current = this.preview.page + 1;
+        let max = this.preview.numPages;
+        let text = _("chapter %s of %s").format(current, max);
+
+        this._label.set_text(text);
+        this._level.set_value(current);
+    },
+
+    createBarWidget: function() {
+        let barWidget = new EPUBBarWidget({ orientation: Gtk.Orientation.HORIZONTAL,
+                                            spacing: 10 });
+
+        this._label = new Gtk.Label();
+        barWidget.add(this._label);
+
+        this._level = new Gtk.Scale({ orientation: Gtk.Orientation.HORIZONTAL });
+        this._level.set_increments(1.0, 1.0);
+        this._level.set_draw_value(false);
+        this._level.set_digits(0);
+        barWidget.pack_start(this._level, true, true, 5);
+        this._level.connect('value-changed', Lang.bind(this, function() {
+            if (this._epubdoc != null)
+                this._epubdoc.set_page(this._level.get_value() - 1);
+        }));
+
+        return barWidget;
+    }
+});
+
+// This class is needed to change the css_name of the widget, to style as a
+// toolbar, with round borders and the correct padding. Doing this we'll
+// have the same styles as GdNavBar
+const EPUBBarWidget = new Lang.Class({
+    Name: 'EPUBBarWidget',
+    Extends: Gtk.Box,
+    CssName: 'toolbar'
+});
