@@ -544,10 +544,6 @@ const EvinceView = new Lang.Class({
         return metadata;
     },
 
-    getModel: function() {
-        return this._model;
-    },
-
     goPrev: function() {
         this._evView.previous_page();
     },
@@ -583,9 +579,7 @@ const EvinceViewNavControls = new Lang.Class({
     Extends: Preview.PreviewNavControls,
 
     createBarWidget: function() {
-        let barWidget = new GdPrivate.NavBar({ margin: Preview.PREVIEW_NAVBAR_MARGIN,
-                                               valign: Gtk.Align.END,
-                                               opacity: 0 });
+        let barWidget = new GdPrivate.NavBar();
 
         let buttonArea = barWidget.get_button_area();
 
