@@ -750,7 +750,6 @@ const ViewContainer = new Lang.Class({
     _init: function(overview, windowMode) {
         this._edgeHitId = 0;
         this._mode = windowMode;
-        this._overview = overview;
 
         this._model = new ViewModel(this._mode);
 
@@ -784,9 +783,9 @@ const ViewContainer = new Lang.Class({
         this.view.connect('notify::view-type',
                           Lang.bind(this, this._onViewTypeChanged));
 
-        let selectionModeAction = this._overview.getAction('selection-mode');
-        selectionModeAction.connect('notify::state', Lang.bind(this, this._onSelectionModeChanged));
-        this._onSelectionModeChanged(selectionModeAction);
+        this._selectionModeAction = overview.getAction('selection-mode');
+        this._selectionModeAction.connect('notify::state', Lang.bind(this, this._onSelectionModeChanged));
+        this._onSelectionModeChanged();
 
         Application.modeController.connect('window-mode-changed',
             Lang.bind(this, this._onWindowModeChanged));
@@ -902,7 +901,7 @@ const ViewContainer = new Lang.Class({
     },
 
     _onSelectionModeRequest: function() {
-        this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', true));
+        this._selectionModeAction.change_state(GLib.Variant.new('b', true));
     },
 
     _onItemActivated: function(widget, id, path) {
@@ -979,8 +978,8 @@ const ViewContainer = new Lang.Class({
         Application.selectionController.setSelection(newSelection);
     },
 
-    _onSelectionModeChanged: function(action) {
-        let selectionMode = action.state.get_boolean();
+    _onSelectionModeChanged: function() {
+        let selectionMode = this._selectionModeAction.state.get_boolean();
         this.view.set_selection_mode(selectionMode);
     },
 
@@ -1037,6 +1036,10 @@ const OverviewStack = new Lang.Class({
         this.parent({ orientation: Gtk.Orientation.VERTICAL,
                       visible: true });
 
+        let actions = this._getDefaultActions();
+        this.actionGroup = new Gio.SimpleActionGroup();
+        Utils.populateActionGroup(this.actionGroup, actions, 'view');
+
         this._stack = new Gtk.Stack({ visible: true });
         this.pack_start(this._stack, true, true, 0);
 
@@ -1044,10 +1047,6 @@ const OverviewStack = new Lang.Class({
         this._selectionToolbar = new Selections.SelectionToolbar(this);
         this.pack_end(this._selectionToolbar, false, false, 0);
 
-        let actions = this._getDefaultActions();
-        this.actionGroup = new Gio.SimpleActionGroup();
-        Utils.populateActionGroup(this.actionGroup, actions, 'view');
-
         // now create the actual content widgets
         this._documents = new ViewContainer(this, WindowMode.WindowMode.DOCUMENTS);
         let label = Application.application.isBooks ? _('Books') : _("Documents");
@@ -1064,9 +1063,16 @@ const OverviewStack = new Lang.Class({
     },
 
     _getDefaultActions: function() {
+        let backAccels = ['Back'];
+        if (this.get_direction() == Gtk.TextDirection.LTR)
+            backAccels.push('<Alt>Left');
+        else
+            backAccels.push('<Alt>Right');
+
         return [
             { name: 'go-back',
-              callback: Lang.bind(this, this._goBack) },
+              callback: Lang.bind(this, this._goBack),
+              accels: backAccels },
             { name: 'selection-mode',
               callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
