@@ -857,12 +857,14 @@ const SelectionToolbar = new Lang.Class({
                         'toolbarCollection' ],
 
     _init: function(overview) {
+        this._docToPrint = null;
+        this._docBeginPrintId = 0;
         this._itemListeners = {};
         this._insideRefresh = false;
-        this._overview = overview;
 
         this.parent();
 
+        this._selectionModeAction = overview.getAction('selection-mode');
 
         this._toolbarOpen.connect('clicked', Lang.bind(this, this._onToolbarOpen));
         this._toolbarPrint.connect('clicked', Lang.bind(this, this._onToolbarPrint));
@@ -885,6 +887,24 @@ const SelectionToolbar = new Lang.Class({
         this._onSelectionChanged();
     },
 
+    vfunc_destroy: function() {
+        this._disconnectDocToPrint();
+        this.parent();
+    },
+
+    vfunc_hide: function() {
+        this._disconnectDocToPrint();
+        this.parent();
+    },
+
+    _disconnectDocToPrint: function() {
+        if (this._docToPrint != null && this._docBeginPrintId != 0) {
+            this._docToPrint.disconnect(this._docBeginPrintId);
+            this._docToPrint = null;
+            this._docBeginPrintId = 0;
+        }
+    },
+
     _updateCollectionsButton: function() {
         let windowMode = Application.modeController.getWindowMode();
         let activeCollection = Application.documentManager.getActiveCollection();
@@ -922,7 +942,7 @@ const SelectionToolbar = new Lang.Class({
         let hasSelection = (selection.length > 0);
 
         let showTrash = hasSelection;
-        let showPrint = hasSelection;
+        let showPrint = false;
         let showProperties = hasSelection;
         let showOpen = hasSelection;
         let showShare = hasSelection;
@@ -943,16 +963,22 @@ const SelectionToolbar = new Lang.Class({
                     showShare = false;
 
                 showTrash &= doc.canTrash();
-                showPrint &= !doc.collection;
             }));
 
         showOpen = (apps.length > 0);
 
-        if (selection.length > 1) {
-            showPrint = false;
-            showProperties = false;
+        if (selection.length == 1) {
+            let doc = Application.documentManager.getItemById(selection[0]);
+            doc.load(null, null, Lang.bind(this,
+                function(doc, docModel, error) {
+                    showPrint = doc.canPrint(docModel);
+                    this._toolbarPrint.set_sensitive(showPrint);
+                }));
         }
 
+        if (selection.length > 1)
+            showProperties = false;
+
         let openLabel = null;
         if (apps.length == 1) {
             // Translators: this is the Open action in a context menu
@@ -981,13 +1007,13 @@ const SelectionToolbar = new Lang.Class({
 
         let dialog = new OrganizeCollectionDialog(toplevel);
         dialog.connect('destroy', Lang.bind(this, function() {
-            this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+            this._selectionModeAction.change_state(GLib.Variant.new('b', false));
         }));
     },
 
     _onToolbarOpen: function(widget) {
         let selection = Application.selectionController.getSelection();
-        this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+        this._selectionModeAction.change_state(GLib.Variant.new('b', false));
 
         selection.forEach(Lang.bind(this,
             function(urn) {
@@ -1018,7 +1044,7 @@ const SelectionToolbar = new Lang.Class({
             }));
 
         let deleteNotification = new Notifications.DeleteNotification(docs);
-        this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+        this._selectionModeAction.change_state(GLib.Variant.new('b', false));
     },
 
     _onToolbarProperties: function(widget) {
@@ -1028,7 +1054,7 @@ const SelectionToolbar = new Lang.Class({
         dialog.connect('response', Lang.bind(this,
             function(widget, response) {
                 dialog.destroy();
-                this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+                this._selectionModeAction.change_state(GLib.Variant.new('b', false));
             }));
     },
 
@@ -1038,7 +1064,7 @@ const SelectionToolbar = new Lang.Class({
        dialog.connect('response', Lang.bind(this,
            function(widget, response) {
                dialog.destroy();
-               this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+               this._selectionModeAction.change_state(GLib.Variant.new('b', false));
            }));
     },
 
@@ -1048,8 +1074,14 @@ const SelectionToolbar = new Lang.Class({
         if (selection.length != 1)
             return;
 
-        let doc = Application.documentManager.getItemById(selection[0]);
-        doc.print(this.get_toplevel());
-        this._overview.getAction('selection-mode').change_state(GLib.Variant.new('b', false));
+        this._disconnectDocToPrint();
+
+        this._docToPrint = Application.documentManager.getItemById(selection[0]);
+        this._docBeginPrintId = this._docToPrint.connect('begin-print', Lang.bind(this,
+            function(doc) {
+                this._selectionModeAction.change_state(GLib.Variant.new('b', false));
+            }));
+
+        this._docToPrint.print(this.get_toplevel());
     },
 });
